# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/spark/v1alpha1/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/msp/spark/v1alpha1/common.proto\x12\x19nebius.msp.spark.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\"O\n\x0cPythonConfig\x12\"\n\x0crequirements\x18\x01 \x03(\tR\x0crequirements\x12\x1b\n\tfile_uris\x18\x02 \x03(\tR\x08\x66ileUris\"?\n\nJavaConfig\x12\x31\n\x10\x65ntrypoint_class\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0f\x65ntrypointClassBj\n ai.nebius.pub.msp.spark.v1alpha1B\x0b\x43ommonProtoP\x01Z7github.com/nebius/gosdk/proto/nebius/msp/spark/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.spark.v1alpha1.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n ai.nebius.pub.msp.spark.v1alpha1B\013CommonProtoP\001Z7github.com/nebius/gosdk/proto/nebius/msp/spark/v1alpha1'
  _JAVACONFIG.fields_by_name['entrypoint_class']._options = None
  _JAVACONFIG.fields_by_name['entrypoint_class']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PYTHONCONFIG']._serialized_start=98
  _globals['_PYTHONCONFIG']._serialized_end=177
  _globals['_JAVACONFIG']._serialized_start=179
  _globals['_JAVACONFIG']._serialized_end=242
# @@protoc_insertion_point(module_scope)
