# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/spark/v1alpha1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.msp.spark.v1alpha1 import cluster_pb2 as nebius_dot_msp_dot_spark_dot_v1alpha1_dot_cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/nebius/msp/spark/v1alpha1/cluster_service.proto\x12\x19nebius.msp.spark.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x18nebius/annotations.proto\x1a\'nebius/msp/spark/v1alpha1/cluster.proto\"+\n\x11GetClusterRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"Z\n\x17GetClusterByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"\x7f\n\x13ListClustersRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12$\n\tpage_size\x18\x02 \x01(\x03\x42\x07\xbaH\x04\"\x02(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x99\x01\n\x14ListClustersResponse\x12@\n\x05items\x18\x01 \x03(\x0b\x32\".nebius.msp.spark.v1alpha1.ClusterB\x06\xbaH\x03\xc8\x01\x01R\x05items\x12+\n\x0fnext_page_token\x18\x02 \x01(\tH\x00R\rnextPageToken\x88\x01\x01\x42\x12\n\x10_next_page_token\"\x81\x03\n\x14\x43reateClusterRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x42\n\x04spec\x18\x02 \x01(\x0b\x32&.nebius.msp.spark.v1alpha1.ClusterSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec:\xdc\x01\xbaH\xd8\x01\x1a\x7f\n\x17\x63reate_cluster.metadata\x12+\'metadata\' must have \'parent_id\' and \'name\'\x1a\x37has(this.metadata.parent_id) && has(this.metadata.name)\x1aU\n\x13\x63reate_cluster.spec\x12 \'spec\' must have \'authorization\'\x1a\x1chas(this.spec.authorization)\"\xec\x01\n\x14UpdateClusterRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12:\n\x04spec\x18\x02 \x01(\x0b\x32&.nebius.msp.spark.v1alpha1.ClusterSpecR\x04spec:P\xbaHM\x1aK\n\x17update_cluster.metadata\x12\x19\'metadata\' must have \'id\'\x1a\x15has(this.metadata.id)\".\n\x14\x44\x65leteClusterRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\xca\x04\n\x0e\x43lusterService\x12W\n\x03Get\x12,.nebius.msp.spark.v1alpha1.GetClusterRequest\x1a\".nebius.msp.spark.v1alpha1.Cluster\x12\x63\n\tGetByName\x12\x32.nebius.msp.spark.v1alpha1.GetClusterByNameRequest\x1a\".nebius.msp.spark.v1alpha1.Cluster\x12g\n\x04List\x12..nebius.msp.spark.v1alpha1.ListClustersRequest\x1a/.nebius.msp.spark.v1alpha1.ListClustersResponse\x12V\n\x06\x43reate\x12/.nebius.msp.spark.v1alpha1.CreateClusterRequest\x1a\x1b.nebius.common.v1.Operation\x12V\n\x06Update\x12/.nebius.msp.spark.v1alpha1.UpdateClusterRequest\x1a\x1b.nebius.common.v1.Operation\x12V\n\x06\x44\x65lete\x12/.nebius.msp.spark.v1alpha1.DeleteClusterRequest\x1a\x1b.nebius.common.v1.Operation\x1a\t\xbaJ\x06sp.mspBr\n ai.nebius.pub.msp.spark.v1alpha1B\x13\x43lusterServiceProtoP\x01Z7github.com/nebius/gosdk/proto/nebius/msp/spark/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.spark.v1alpha1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n ai.nebius.pub.msp.spark.v1alpha1B\023ClusterServiceProtoP\001Z7github.com/nebius/gosdk/proto/nebius/msp/spark/v1alpha1'
  _GETCLUSTERREQUEST.fields_by_name['id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETCLUSTERBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETCLUSTERBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETCLUSTERBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETCLUSTERBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTCLUSTERSREQUEST.fields_by_name['parent_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._serialized_options = b'\272H\004\"\002(\000'
  _LISTCLUSTERSRESPONSE.fields_by_name['items']._options = None
  _LISTCLUSTERSRESPONSE.fields_by_name['items']._serialized_options = b'\272H\003\310\001\001'
  _CREATECLUSTERREQUEST.fields_by_name['metadata']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CREATECLUSTERREQUEST.fields_by_name['spec']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _CREATECLUSTERREQUEST._options = None
  _CREATECLUSTERREQUEST._serialized_options = b'\272H\330\001\032\177\n\027create_cluster.metadata\022+\'metadata\' must have \'parent_id\' and \'name\'\0327has(this.metadata.parent_id) && has(this.metadata.name)\032U\n\023create_cluster.spec\022 \'spec\' must have \'authorization\'\032\034has(this.spec.authorization)'
  _UPDATECLUSTERREQUEST.fields_by_name['metadata']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _UPDATECLUSTERREQUEST._options = None
  _UPDATECLUSTERREQUEST._serialized_options = b'\272HM\032K\n\027update_cluster.metadata\022\031\'metadata\' must have \'id\'\032\025has(this.metadata.id)'
  _DELETECLUSTERREQUEST.fields_by_name['id']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTERSERVICE._options = None
  _CLUSTERSERVICE._serialized_options = b'\272J\006sp.msp'
  _globals['_GETCLUSTERREQUEST']._serialized_start=241
  _globals['_GETCLUSTERREQUEST']._serialized_end=284
  _globals['_GETCLUSTERBYNAMEREQUEST']._serialized_start=286
  _globals['_GETCLUSTERBYNAMEREQUEST']._serialized_end=376
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=378
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=505
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=508
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=661
  _globals['_CREATECLUSTERREQUEST']._serialized_start=664
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1049
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1052
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=1288
  _globals['_DELETECLUSTERREQUEST']._serialized_start=1290
  _globals['_DELETECLUSTERREQUEST']._serialized_end=1336
  _globals['_CLUSTERSERVICE']._serialized_start=1339
  _globals['_CLUSTERSERVICE']._serialized_end=1925
# @@protoc_insertion_point(module_scope)
