# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/spark/v1alpha1/session.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.msp.spark.v1alpha1 import common_pb2 as nebius_dot_msp_dot_spark_dot_v1alpha1_dot_common__pb2
from nebius.api.nebius.msp.spark.v1alpha1 import preset_pb2 as nebius_dot_msp_dot_spark_dot_v1alpha1_dot_preset__pb2
from nebius.api.nebius.msp.v1alpha1 import cluster_pb2 as nebius_dot_msp_dot_v1alpha1_dot_cluster__pb2
from nebius.api.nebius.msp.v1alpha1.resource import template_pb2 as nebius_dot_msp_dot_v1alpha1_dot_resource_dot_template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'nebius/msp/spark/v1alpha1/session.proto\x12\x19nebius.msp.spark.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a&nebius/msp/spark/v1alpha1/common.proto\x1a&nebius/msp/spark/v1alpha1/preset.proto\x1a!nebius/msp/v1alpha1/cluster.proto\x1a+nebius/msp/v1alpha1/resource/template.proto\"\xdd\x01\n\x07Session\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x42\n\x04spec\x18\x02 \x01(\x0b\x32&.nebius.msp.spark.v1alpha1.SessionSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12\x46\n\x06status\x18\x03 \x01(\x0b\x32(.nebius.msp.spark.v1alpha1.SessionStatusB\x04\xbaJ\x01\x05R\x06status\"\xbf\x04\n\x0bSessionSpec\x12%\n\x0b\x64\x65scription\x18\x01 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12M\n\x06\x64river\x18\x02 \x01(\x0b\x32-.nebius.msp.spark.v1alpha1.DriverTemplateSpecB\x06\xbaH\x03\xc8\x01\x01R\x06\x64river\x12S\n\x08\x65xecutor\x18\x03 \x01(\x0b\x32/.nebius.msp.spark.v1alpha1.ExecutorTemplateSpecB\x06\xbaH\x03\xc8\x01\x01R\x08\x65xecutor\x12+\n\rspark_version\x18\x04 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0csparkVersion\x12\x1b\n\tfile_uris\x18\x65 \x03(\tR\x08\x66ileUris\x12\x19\n\x08jar_uris\x18\x66 \x03(\tR\x07jarUris\x12\x1a\n\x08packages\x18g \x03(\tR\x08packages\x12T\n\nspark_conf\x18h \x03(\x0b\x32\x35.nebius.msp.spark.v1alpha1.SessionSpec.SparkConfEntryR\tsparkConf\x12@\n\x06python\x18\xc9\x01 \x01(\x0b\x32\'.nebius.msp.spark.v1alpha1.PythonConfigR\x06python\x1a<\n\x0eSparkConfEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0e\n\x0c_description\"\xab\x03\n\rSessionStatus\x12>\n\x05phase\x18\x01 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.PhaseR\x05phase\x12>\n\x05state\x18\x02 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.StateR\x05state\x12\x39\n\x16spark_connect_endpoint\x18\x03 \x01(\tH\x00R\x14sparkConnectEndpoint\x88\x01\x01\x12_\n\x15\x64river_preset_details\x18\x04 \x01(\x0b\x32+.nebius.msp.v1alpha1.resource.PresetDetailsR\x13\x64riverPresetDetails\x12\x63\n\x17\x65xecutor_preset_details\x18\x05 \x01(\x0b\x32+.nebius.msp.v1alpha1.resource.PresetDetailsR\x15\x65xecutorPresetDetailsB\x19\n\x17_spark_connect_endpointBk\n ai.nebius.pub.msp.spark.v1alpha1B\x0cSessionProtoP\x01Z7github.com/nebius/gosdk/proto/nebius/msp/spark/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.spark.v1alpha1.session_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n ai.nebius.pub.msp.spark.v1alpha1B\014SessionProtoP\001Z7github.com/nebius/gosdk/proto/nebius/msp/spark/v1alpha1'
  _SESSION.fields_by_name['metadata']._options = None
  _SESSION.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _SESSION.fields_by_name['spec']._options = None
  _SESSION.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _SESSION.fields_by_name['status']._options = None
  _SESSION.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _SESSIONSPEC_SPARKCONFENTRY._options = None
  _SESSIONSPEC_SPARKCONFENTRY._serialized_options = b'8\001'
  _SESSIONSPEC.fields_by_name['driver']._options = None
  _SESSIONSPEC.fields_by_name['driver']._serialized_options = b'\272H\003\310\001\001'
  _SESSIONSPEC.fields_by_name['executor']._options = None
  _SESSIONSPEC.fields_by_name['executor']._serialized_options = b'\272H\003\310\001\001'
  _SESSIONSPEC.fields_by_name['spark_version']._options = None
  _SESSIONSPEC.fields_by_name['spark_version']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SESSION']._serialized_start=319
  _globals['_SESSION']._serialized_end=540
  _globals['_SESSIONSPEC']._serialized_start=543
  _globals['_SESSIONSPEC']._serialized_end=1118
  _globals['_SESSIONSPEC_SPARKCONFENTRY']._serialized_start=1042
  _globals['_SESSIONSPEC_SPARKCONFENTRY']._serialized_end=1102
  _globals['_SESSIONSTATUS']._serialized_start=1121
  _globals['_SESSIONSTATUS']._serialized_end=1548
# @@protoc_insertion_point(module_scope)
