# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/spark/v1alpha1/preset.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.msp.v1alpha1.resource import template_pb2 as nebius_dot_msp_dot_v1alpha1_dot_resource_dot_template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/msp/spark/v1alpha1/preset.proto\x12\x19nebius.msp.spark.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a+nebius/msp/v1alpha1/resource/template.proto\"\xa3\x01\n\x12\x44riverTemplateSpec\x12\x42\n\x04\x64isk\x18\x03 \x01(\x0b\x32&.nebius.msp.v1alpha1.resource.DiskSpecB\x06\xbaH\x03\xc8\x01\x01R\x04\x64isk\x12I\n\tresources\x18\x04 \x01(\x0b\x32+.nebius.msp.v1alpha1.resource.ResourcesSpecR\tresources\"K\n\x15\x44ynamicAllocationSpec\x12\x18\n\x03min\x18\x01 \x01(\x03\x42\x06\xbaH\x03\xc8\x01\x01R\x03min\x12\x18\n\x03max\x18\x02 \x01(\x03\x42\x06\xbaH\x03\xc8\x01\x01R\x03max\"\xe8\x02\n\x14\x45xecutorTemplateSpec\x12\x42\n\x04\x64isk\x18\x02 \x01(\x0b\x32&.nebius.msp.v1alpha1.resource.DiskSpecB\x06\xbaH\x03\xc8\x01\x01R\x04\x64isk\x12I\n\tresources\x18\x04 \x01(\x0b\x32+.nebius.msp.v1alpha1.resource.ResourcesSpecR\tresources\x12>\n\x05hosts\x18\x65 \x01(\x0b\x32&.nebius.msp.v1alpha1.resource.HostSpecH\x00R\x05hosts\x12l\n\x18hosts_dynamic_allocation\x18\x66 \x01(\x0b\x32\x30.nebius.msp.spark.v1alpha1.DynamicAllocationSpecH\x00R\x16hostsDynamicAllocationB\x13\n\nhosts_spec\x12\x05\xbaH\x02\x08\x01\x42j\n ai.nebius.pub.msp.spark.v1alpha1B\x0bPresetProtoP\x01Z7github.com/nebius/gosdk/proto/nebius/msp/spark/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.spark.v1alpha1.preset_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n ai.nebius.pub.msp.spark.v1alpha1B\013PresetProtoP\001Z7github.com/nebius/gosdk/proto/nebius/msp/spark/v1alpha1'
  _DRIVERTEMPLATESPEC.fields_by_name['disk']._options = None
  _DRIVERTEMPLATESPEC.fields_by_name['disk']._serialized_options = b'\272H\003\310\001\001'
  _DYNAMICALLOCATIONSPEC.fields_by_name['min']._options = None
  _DYNAMICALLOCATIONSPEC.fields_by_name['min']._serialized_options = b'\272H\003\310\001\001'
  _DYNAMICALLOCATIONSPEC.fields_by_name['max']._options = None
  _DYNAMICALLOCATIONSPEC.fields_by_name['max']._serialized_options = b'\272H\003\310\001\001'
  _EXECUTORTEMPLATESPEC.oneofs_by_name['hosts_spec']._options = None
  _EXECUTORTEMPLATESPEC.oneofs_by_name['hosts_spec']._serialized_options = b'\272H\002\010\001'
  _EXECUTORTEMPLATESPEC.fields_by_name['disk']._options = None
  _EXECUTORTEMPLATESPEC.fields_by_name['disk']._serialized_options = b'\272H\003\310\001\001'
  _globals['_DRIVERTEMPLATESPEC']._serialized_start=144
  _globals['_DRIVERTEMPLATESPEC']._serialized_end=307
  _globals['_DYNAMICALLOCATIONSPEC']._serialized_start=309
  _globals['_DYNAMICALLOCATIONSPEC']._serialized_end=384
  _globals['_EXECUTORTEMPLATESPEC']._serialized_start=387
  _globals['_EXECUTORTEMPLATESPEC']._serialized_end=747
# @@protoc_insertion_point(module_scope)
