# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1alpha1/gpu_cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1alpha1 import operation_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__pb2
from nebius.api.nebius.common.v1alpha1 import operation_service_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__service__pb2
from nebius.api.nebius.compute.v1alpha1 import gpu_cluster_pb2 as nebius_dot_compute_dot_v1alpha1_dot_gpu__cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1nebius/compute/v1alpha1/gpu_cluster_service.proto\x12\x17nebius.compute.v1alpha1\x1a\x1fnebius/common/v1/metadata.proto\x1a&nebius/common/v1alpha1/operation.proto\x1a.nebius/common/v1alpha1/operation_service.proto\x1a)nebius/compute/v1alpha1/gpu_cluster.proto\"&\n\x14GetGpuClusterRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x89\x01\n\x16ListGpuClustersRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\x96\x01\n\x17\x43reateGpuClusterRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12;\n\x04spec\x18\x02 \x01(\x0b\x32\'.nebius.compute.v1alpha1.GpuClusterSpecR\x04spec\"\x96\x01\n\x17UpdateGpuClusterRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12;\n\x04spec\x18\x02 \x01(\x0b\x32\'.nebius.compute.v1alpha1.GpuClusterSpecR\x04spec\")\n\x17\x44\x65leteGpuClusterRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"|\n\x17ListGpuClustersResponse\x12\x39\n\x05items\x18\x01 \x03(\x0b\x32#.nebius.compute.v1alpha1.GpuClusterR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xd2\x05\n\x11GpuClusterService\x12Y\n\x03Get\x12-.nebius.compute.v1alpha1.GetGpuClusterRequest\x1a#.nebius.compute.v1alpha1.GpuCluster\x12T\n\tGetByName\x12\".nebius.common.v1.GetByNameRequest\x1a#.nebius.compute.v1alpha1.GpuCluster\x12i\n\x04List\x12/.nebius.compute.v1alpha1.ListGpuClustersRequest\x1a\x30.nebius.compute.v1alpha1.ListGpuClustersResponse\x12]\n\x06\x43reate\x12\x30.nebius.compute.v1alpha1.CreateGpuClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12]\n\x06Update\x12\x30.nebius.compute.v1alpha1.UpdateGpuClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12]\n\x06\x44\x65lete\x12\x30.nebius.compute.v1alpha1.DeleteGpuClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12\x7f\n\x16ListOperationsByParent\x12\x35.nebius.common.v1alpha1.ListOperationsByParentRequest\x1a..nebius.common.v1alpha1.ListOperationsResponse\x1a\x03\x88\x02\x01\x42t\n\x1e\x61i.nebius.pub.compute.v1alpha1B\x16GpuClusterServiceProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/compute/v1alpha1\xb8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1alpha1.gpu_cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.compute.v1alpha1B\026GpuClusterServiceProtoP\001Z5github.com/nebius/gosdk/proto/nebius/compute/v1alpha1\270\001\001'
  _GPUCLUSTERSERVICE._options = None
  _GPUCLUSTERSERVICE._serialized_options = b'\210\002\001'
  _globals['_GETGPUCLUSTERREQUEST']._serialized_start=242
  _globals['_GETGPUCLUSTERREQUEST']._serialized_end=280
  _globals['_LISTGPUCLUSTERSREQUEST']._serialized_start=283
  _globals['_LISTGPUCLUSTERSREQUEST']._serialized_end=420
  _globals['_CREATEGPUCLUSTERREQUEST']._serialized_start=423
  _globals['_CREATEGPUCLUSTERREQUEST']._serialized_end=573
  _globals['_UPDATEGPUCLUSTERREQUEST']._serialized_start=576
  _globals['_UPDATEGPUCLUSTERREQUEST']._serialized_end=726
  _globals['_DELETEGPUCLUSTERREQUEST']._serialized_start=728
  _globals['_DELETEGPUCLUSTERREQUEST']._serialized_end=769
  _globals['_LISTGPUCLUSTERSRESPONSE']._serialized_start=771
  _globals['_LISTGPUCLUSTERSRESPONSE']._serialized_end=895
  _globals['_GPUCLUSTERSERVICE']._serialized_start=898
  _globals['_GPUCLUSTERSERVICE']._serialized_end=1620
# @@protoc_insertion_point(module_scope)
