# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/v1alpha1/resource/preset.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.msp.v1alpha1.resource import template_pb2 as nebius_dot_msp_dot_v1alpha1_dot_resource_dot_template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)nebius/msp/v1alpha1/resource/preset.proto\x12\x1cnebius.msp.v1alpha1.resource\x1a\x1b\x62uf/validate/validate.proto\x1a+nebius/msp/v1alpha1/resource/template.proto\"N\n\x06Preset\x12\x44\n\x04spec\x18\x02 \x01(\x0b\x32(.nebius.msp.v1alpha1.resource.PresetSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"\xe4\x01\n\nPresetSpec\x12H\n\x06\x66lavor\x18\x01 \x01(\x0b\x32(.nebius.msp.v1alpha1.resource.FlavorSpecB\x06\xbaH\x03\xc8\x01\x01R\x06\x66lavor\x12\x38\n\x05hosts\x18\x02 \x01(\x0b\x32\".nebius.msp.v1alpha1.resource.HostR\x05hosts\x12\x36\n\x04\x64isk\x18\x03 \x01(\x0b\x32\".nebius.msp.v1alpha1.resource.DiskR\x04\x64isk\x12\x1a\n\x04role\x18\x04 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04role\"\x97\x01\n\nFlavorSpec\x12?\n\x03\x63pu\x18\x01 \x01(\x0b\x32%.nebius.msp.v1alpha1.resource.CpuSpecB\x06\xbaH\x03\xc8\x01\x01R\x03\x63pu\x12H\n\x06memory\x18\x02 \x01(\x0b\x32(.nebius.msp.v1alpha1.resource.MemorySpecB\x06\xbaH\x03\xc8\x01\x01R\x06memory\"O\n\x07\x43puSpec\x12\x1c\n\x05\x63ount\x18\x01 \x01(\x05\x42\x06\xbaH\x03\xc8\x01\x01R\x05\x63ount\x12&\n\ngeneration\x18\x02 \x01(\x05\x42\x06\xbaH\x03\xc8\x01\x01R\ngeneration\"=\n\nMemorySpec\x12/\n\x0flimit_gibibytes\x18\x01 \x01(\x03\x42\x06\xbaH\x03\xc8\x01\x01R\x0elimitGibibytesBp\n#ai.nebius.pub.msp.v1alpha1.resourceB\x0bPresetProtoP\x01Z:github.com/nebius/gosdk/proto/nebius/msp/v1alpha1/resourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.v1alpha1.resource.preset_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#ai.nebius.pub.msp.v1alpha1.resourceB\013PresetProtoP\001Z:github.com/nebius/gosdk/proto/nebius/msp/v1alpha1/resource'
  _PRESET.fields_by_name['spec']._options = None
  _PRESET.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _PRESETSPEC.fields_by_name['flavor']._options = None
  _PRESETSPEC.fields_by_name['flavor']._serialized_options = b'\272H\003\310\001\001'
  _PRESETSPEC.fields_by_name['role']._options = None
  _PRESETSPEC.fields_by_name['role']._serialized_options = b'\272H\003\310\001\001'
  _FLAVORSPEC.fields_by_name['cpu']._options = None
  _FLAVORSPEC.fields_by_name['cpu']._serialized_options = b'\272H\003\310\001\001'
  _FLAVORSPEC.fields_by_name['memory']._options = None
  _FLAVORSPEC.fields_by_name['memory']._serialized_options = b'\272H\003\310\001\001'
  _CPUSPEC.fields_by_name['count']._options = None
  _CPUSPEC.fields_by_name['count']._serialized_options = b'\272H\003\310\001\001'
  _CPUSPEC.fields_by_name['generation']._options = None
  _CPUSPEC.fields_by_name['generation']._serialized_options = b'\272H\003\310\001\001'
  _MEMORYSPEC.fields_by_name['limit_gibibytes']._options = None
  _MEMORYSPEC.fields_by_name['limit_gibibytes']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PRESET']._serialized_start=149
  _globals['_PRESET']._serialized_end=227
  _globals['_PRESETSPEC']._serialized_start=230
  _globals['_PRESETSPEC']._serialized_end=458
  _globals['_FLAVORSPEC']._serialized_start=461
  _globals['_FLAVORSPEC']._serialized_end=612
  _globals['_CPUSPEC']._serialized_start=614
  _globals['_CPUSPEC']._serialized_end=693
  _globals['_MEMORYSPEC']._serialized_start=695
  _globals['_MEMORYSPEC']._serialized_end=756
# @@protoc_insertion_point(module_scope)
